summaryrefslogtreecommitdiffstats
path: root/bibletime/backend/cswordmoduleinfo.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:29:22 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:29:22 -0600
commitb3e956791016cf9eb1bf6a2138066bdd4d4cab8a (patch)
treef597165839e56186e005ee331ac5a88a1cdb5739 /bibletime/backend/cswordmoduleinfo.cpp
parent9eb680e22cbcae634c6ff3833eddaff9e3be40e7 (diff)
downloadbibletime-b3e956791016cf9eb1bf6a2138066bdd4d4cab8a.tar.gz
bibletime-b3e956791016cf9eb1bf6a2138066bdd4d4cab8a.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'bibletime/backend/cswordmoduleinfo.cpp')
-rw-r--r--bibletime/backend/cswordmoduleinfo.cpp56
1 files changed, 28 insertions, 28 deletions
diff --git a/bibletime/backend/cswordmoduleinfo.cpp b/bibletime/backend/cswordmoduleinfo.cpp
index ebb0cc3..ecb03d0 100644
--- a/bibletime/backend/cswordmoduleinfo.cpp
+++ b/bibletime/backend/cswordmoduleinfo.cpp
@@ -153,13 +153,13 @@ const bool CSwordModuleInfo::unlockKeyIsValid() {
(*m_module) = sword::TOP;
// This needs to use ::tqfromLatin1 because if the text is still locked,
// a lot of garbage will show up. It will also work with properly decrypted
// Unicode text, because all non-ASCII Unicode chars consist of bytes >127
// and therefore contain no control (nonprintable) characters, which are all <127.
TQString test = isUnicode()
? TQString::fromUtf8(m_module->getRawEntryBuf().c_str())
- : TQString::tqfromLatin1( m_module->getRawEntryBuf().c_str() );
+ : TQString::fromLatin1( m_module->getRawEntryBuf().c_str() );
if (test.isEmpty()) {
qWarning("Unlock key of module %s is NOT valid", name().latin1());
@@ -714,40 +714,40 @@ TQString CSwordModuleInfo::aboutText() const {
text += "<font size=\"-1\"><table>";
text += TQString("<tr><td><b>%1</b></td><td>%2</td><tr>")
- .tqarg(i18n("Version"))
- .tqarg(hasVersion()? config(CSwordModuleInfo::ModuleVersion) : i18n("unknown"));
+ .arg(i18n("Version"))
+ .arg(hasVersion()? config(CSwordModuleInfo::ModuleVersion) : i18n("unknown"));
text += TQString("<tr><td><b>%1</b></td><td>%2</td></tr>")
- .tqarg(i18n("Markup"))
- .tqarg(!TQString(m_module->getConfigEntry("SourceType")).isEmpty()? m_module->
+ .arg(i18n("Markup"))
+ .arg(!TQString(m_module->getConfigEntry("SourceType")).isEmpty()? m_module->
getConfigEntry("SourceType") : i18n("unknown").ascii());
text += TQString("<tr><td><b>%1</b></td><td>%2</td></tr>")
- .tqarg(i18n("Location"))
- .tqarg(config(CSwordModuleInfo::AbsoluteDataPath));
+ .arg(i18n("Location"))
+ .arg(config(CSwordModuleInfo::AbsoluteDataPath));
text += TQString("<tr><td><b>%1</b></td><td>%2</td></tr>")
- .tqarg(i18n("Language"))
- .tqarg(language()->translatedName());
+ .arg(i18n("Language"))
+ .arg(language()->translatedName());
if (m_module->getConfigEntry("Category"))
text += TQString("<tr><td><b>%1</b></td><td>%2</td></tr>")
- .tqarg(i18n("Category"))
- .tqarg(m_module->getConfigEntry("Category"));
+ .arg(i18n("Category"))
+ .arg(m_module->getConfigEntry("Category"));
if (m_module->getConfigEntry("LCSH"))
text += TQString("<tr><td><b>%1</b></td><td>%2</td></tr>")
- .tqarg(i18n("LCSH"))
- .tqarg(m_module->getConfigEntry("LCSH"));
+ .arg(i18n("LCSH"))
+ .arg(m_module->getConfigEntry("LCSH"));
text += TQString("<tr><td><b>%1</b></td><td>%2</td></tr>")
- .tqarg(i18n("Writable"))
- .tqarg(isWritable()? i18n("yes") : i18n("no"));
+ .arg(i18n("Writable"))
+ .arg(isWritable()? i18n("yes") : i18n("no"));
if (isEncrypted())
text += TQString("<tr><td><b>%1</b></td><td>%2</td></tr>")
- .tqarg(i18n("Unlock key"))
- .tqarg(config(CSwordModuleInfo::CipherKey));
+ .arg(i18n("Unlock key"))
+ .arg(config(CSwordModuleInfo::CipherKey));
TQString options;
@@ -756,7 +756,7 @@ TQString CSwordModuleInfo::aboutText() const {
for (opts = CSwordModuleInfo::filterTypesMIN; opts <= CSwordModuleInfo::filterTypesMAX; ++opts) {
if (has(static_cast < CSwordModuleInfo::FilterTypes > (opts))) {
if (!options.isEmpty()) {
- options += TQString::tqfromLatin1(", ");
+ options += TQString::fromLatin1(", ");
}
options += CSwordBackend::translatedOptionName(static_cast < CSwordModuleInfo::FilterTypes > (opts));
@@ -765,19 +765,19 @@ TQString CSwordModuleInfo::aboutText() const {
if (!options.isEmpty()) {
text += TQString("<tr><td><b>%1</b></td><td>%2</td></tr>")
- .tqarg(i18n("Features"))
- .tqarg(options);
+ .arg(i18n("Features"))
+ .arg(options);
}
text += "</table><hr>";
if (category() == Cult) //clearly say the module contains cult/questionable materials
text += TQString("<br/><b>%1</b><br/><br/>")
- .tqarg(i18n("Take care, this work contains cult / questionable material!"));
+ .arg(i18n("Take care, this work contains cult / questionable material!"));
text += TQString("<b>%1:</b><br><font size=\"-1\">%2</font>")
- .tqarg(i18n("About"))
- .tqarg(config(AboutInformation));
+ .arg(i18n("About"))
+ .arg(config(AboutInformation));
typedef TQValueList<CSwordModuleInfo::ConfigEntry> ListConfigEntry;
@@ -834,8 +834,8 @@ TQString CSwordModuleInfo::aboutText() const {
if (!t.isEmpty()) {
text += TQString("<tr><td><b>%1</b></td><td>%2</td></tr>")
- .tqarg(entryMap[*it])
- .tqarg(config(*it));
+ .arg(entryMap[*it])
+ .arg(config(*it));
}
}
@@ -871,7 +871,7 @@ const CLanguageMgr::Language * const CSwordModuleInfo::language() const {
TQString CSwordModuleInfo::getSimpleConfigEntry(const TQString& name) const {
TQString ret = isUnicode()
? TQString::fromUtf8(m_module->getConfigEntry(name.latin1()))
- : TQString::tqfromLatin1(m_module->getConfigEntry(name.latin1()));
+ : TQString::fromLatin1(m_module->getConfigEntry(name.latin1()));
return ret.isEmpty() ? TQString() : ret;
}
@@ -882,7 +882,7 @@ TQString CSwordModuleInfo::getFormattedConfigEntry(const TQString& name) const {
RTF_Filter.processText(RTF_Buffer, 0, 0);
TQString ret = isUnicode()
? TQString::fromUtf8(RTF_Buffer.c_str())
- : TQString::tqfromLatin1(RTF_Buffer.c_str());
+ : TQString::fromLatin1(RTF_Buffer.c_str());
return ret.isEmpty() ? TQString() : ret;
}
@@ -153,13 +153,13 @@ const bool CSwordModuleInfo::unlockKeyIsValid() {
(*m_module) = sword::TOP;
- // This needs to use ::tqfromLatin1 because if the text is still locked,
+ // This needs to use ::fromLatin1 because if the text is still locked,
// a lot of garbage will show up. It will also work with properly decrypted
// Unicode text, because all non-ASCII Unicode chars consist of bytes >127